#
#
# $Id: appcfg.rb,v 1.26 2004/05/08 00:50:31 Yuukis Exp $
#
#

class CFG
	RSS_STRING = 'rss'
	CFG_SUFFIX = '.cfg'
	NG_WORDS_DAT = 'ngwords.dat'

	# define SYS
		sys = Struct.new('System',
			:root,
			:siteroot,
			:monazilla,
			:app_name,
			:app_name_dir
			)
		SYS = sys.new()

	# define Regex
		regex = Struct.new('Regex',
			:id,
			:head_id,
			:follow,
			:follow_many,
			:quote,
			:uri,
			:uri_2ch,
			:uri_2ch_board
			)
		Regex = regex.new(
			/^\d/,
			/^(\d+)/,
			/^(.*?)([>]{1,2}[\d-]+)(.*)/e,
			/^(.*?)([>]{1,2}[\d-]+[-=,]\s?\d+)(.*)/e,
			/^\s[>](?![>]?\d+).*/e,
			/^(.*?)([h|f]?t?tps?:[a-zA-Z0-9%&\?\/\;\:\@\&\=\+\$\,\-\_\.\!\~\*\'\\#]+)(.*)$/,
			/^(.*?)h?ttp:\/\/.+\.(2ch\.net|bbspink\.com)\/test\/read\.cgi\/(\S+)\/(\d+)(.*)$/,
			/^h?ttp:\/\/.+\.(?:2ch\.net|bbspink\.com)\/(.*)\/$/
			)

	# define UIF
		uif = Struct.new('UserInterFace',
			:board_position, 
			:board_start_open, 
			:bm_button_position,
			:tab_width,
			:tabbutton_type,
			:favorite_buttons,
			:width,
			:height,
			:thread_auto_next,
			:postbox_auto_scroll,
			:postbox_border,
			:postbox_height,
			:boardselect_border,
			:boardselect_width,
			:bs_active,
			:bs_nonactive,
			:searched_max
		)
		UIF = uif.new(true, false, true, 6, 2, 0, 525, 450, true, true, 0, 250, 0, 200, 0, 0, 10)
		D_UIF = uif.new(true, false, true, 6, 2, 0, 525, 450, true, true, 0, 250, 0, 200, 0, 0, 10)

	# define EXT
		ext = Struct.new('ExtendModules',
			:http_cmd,
			:migemo_flag,
			:migemo_dict,
			:migemo_dict_cache,
			:migemo_length
		)
		EXT = ext.new('mozilla -noraise -remote "openurl(%d)"', false, '', '', 3)
		D_EXT = ext.new('mozilla -noraise -remote "openurl(%d)"', false, '', '', 3)

	# define Proxy
		proxy = Struct.new('ProxyServers',
			:get_addr,
			:get_port,
			:post_addr,
			:post_port
		)
		Proxy = proxy.new()
		D_Proxy = proxy.new()

	# define Color
		color = Struct.new('Colors',
			:thread_base_fg,
			:thread_quote_fg,
			:thread_header_fg,
			:thread_followup_fg,
			:thread_uri_fg,
			#
			:bookmark_bg,
			:abone_bg
		)
		Color = color.new(
			[ 0, 0, 0 ], [ 32896, 0, 32896 ], [ 0, 25700, 0 ], [ 0, 0, 65535 ], [ 0, 0, 65535 ],
			[ 55000, 55000, 55000 ], [ 63052, 46028, 48793 ]
			)
		D_Color = color.new(
			[ 0, 0, 0 ], [ 32896, 0, 32896 ], [ 0, 25700, 0 ], [ 0, 0, 65535 ], [ 0, 0, 65535 ],
			[ 55000, 55000, 55000 ], [ 63052, 46028, 48793 ]
			)

	# define GDK_Color => Gdk::Color
		GDK_Color = color.new()

	# define Identity
		identity = Struct.new('Identity',
			:myfavorites,
			:name,
			:mailto
		)
		Identity = identity.new([], '̵̾', 'sage')
		D_Identity = identity.new([], '̵̾', 'sage')

	# define Net
		net = Struct.new('Network',
			:bbsmenu_check,
			:bbsmenu_url,
			:ng_word
		)
		Net = net.new(false, 'http://www.ff.iij4u.or.jp/~ch2/bbsmenu.html', {})
		D_Net = net.new(false, 'http://www.ff.iij4u.or.jp/~ch2/bbsmenu.html', {})

	# define RSS
		rss = Struct.new('RSS',
			:sites,
			:cfg
		)
		RSS = rss.new([], RSS_STRING + CFG_SUFFIX)
		#D_RSS = rss.new([], RSS_STRING + CFG_SUFFIX)

	# end 

	def CFG.init(app_root, app_name)
		SYS.app_name = app_name
		SYS.app_name_dir = app_root

		SYS.root = "#{ENV['HOME']}/.#{SYS.app_name_dir}/"
		SYS.siteroot = ''
		SYS.monazilla = "Monazilla/1.00 (#{SYS.app_name})"
		Dir.mkdir(SYS.root) unless File.exist?(SYS.root)
	end

	def CFG.load_user_cfg
		cfg = SYS.root + SYS.app_name_dir + CFG_SUFFIX
		eval(IO.readlines(cfg).join) if File.exist?(cfg)

		nwd = SYS.root + NG_WORDS_DAT
		if File.exist?(nwd)
			x = ''
			IO.readlines(nwd).each {|y| x << y.chomp + ',' if y !~ /^#/ }
			x.gsub!(/,\z/, '')
			eval("Net.ng_word = { #{x} }")
		end

		if UIF.board_position  # left
			UIF.bs_active = UIF.boardselect_width
			UIF.bs_nonactive = 0
		else  # right
			UIF.bs_active = UIF.width - UIF.boardselect_width
			UIF.bs_nonactive = 5000
		end

		if EXT.migemo_length < D_EXT.migemo_length
			EXT.migemo_length = D_EXT.migemo_length
		end
	end

	def CFG.load_rss_cfg
		ret = []

		cfg = SYS.root + RSS.cfg
		cfg = SYS.siteroot + RSS.cfg unless File.exist?(cfg)

		IO.readlines(cfg).each {|line|
			case line
			when /^\#/ then
			when /^$/ then
			when /^category:/ then ret << {line.gsub(/^category:\s*/, '').chomp => []}
			else
				x = line.chomp.split('<>')
				hash = {'site' => x[0], 'uri_top' => x[1], 'uri_rss' => x[2], 'dir' => x[3]}
				ret[ret.size-1][ret[ret.size-1].keys.to_s] << hash
			end
		}

		RSS.sites = ret
	end
end
